@@ -9,8 +9,7 @@ Usage::
     data: ArtworkTypeDef = {...}
     ```
 """
-import sys
-from typing import Dict, List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -43,6 +42,7 @@ __all__ = (
     "PlaylistTypeDef",
     "PresetTypeDef",
     "PresetWatermarkTypeDef",
+    "ResponseMetadata",
     "ThumbnailsTypeDef",
     "TimeSpanTypeDef",
     "TimingTypeDef",
@@ -207,6 +207,7 @@ JobOutputTypeDef = TypedDict(
         "Captions": "CaptionsTypeDef",
         "Encryption": "EncryptionTypeDef",
         "AppliedColorSpaceConversion": str,
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
@@ -330,6 +331,17 @@ PresetWatermarkTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadata = TypedDict(
+    "ResponseMetadata",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 ThumbnailsTypeDef = TypedDict(
     "ThumbnailsTypeDef",
     {
@@ -391,6 +403,7 @@ CreateJobOutputTypeDef = TypedDict(
         "Composition": List["ClipTypeDef"],
         "Captions": "CaptionsTypeDef",
         "Encryption": "EncryptionTypeDef",
+        "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
 )
